@@ -22,6 +22,10 @@ class DistributiveSpider(Spider):
         分布式 spider
     """
 
+    def __new__(cls, *args, **kwargs):
+        setattr(settings, 'SPIDER_TYPE', 2)
+        return object.__new__(cls)
+
     def __init__(self, thread_count=None, redis_key: str = None, request_filter=False, item_filter=False):
         """
 
@@ -30,7 +34,6 @@ class DistributiveSpider(Spider):
         :param request_filter: 开启请求过滤，不然 filter_repeat 无效
         :param item_filter: 开启 item 过滤
         """
-        setattr(settings, 'SPIDER_TYPE', 2)
         self.spider_master = False
         self.redis_key = redis_key or self.name
 
