@@ -24,12 +24,13 @@ class ClientHeart:
         self.client_name = self.generate_client_name()  # 随机客户端名
 
     def start(self):
-        threading.Thread(target=self.beating, daemon=True).start()
+        beating = threading.Thread(target=self.beating, daemon=True)
+        beating.start()
 
         try:
             self.check_client_beating()
         finally:
-            self.close()
+            self.close(beating)
 
     def check_client_beating(self):
         """
@@ -106,7 +107,7 @@ class ClientHeart:
             )
             time.sleep(self.beating_time)
 
-    def close(self):
+    def close(self, beating: threading.Thread):
         """
         清理资源
 
@@ -114,7 +115,10 @@ class ClientHeart:
         """
         from palp.conn import redis_conn
 
-        redis_conn.hdel(settings.REDIS_KEY_HEARTBEAT, self.client_name)
+        while True:
+            if not beating.is_alive():
+                redis_conn.hdel(settings.REDIS_KEY_HEARTBEAT, self.client_name)
+                break
 
     @staticmethod
     def stop_all_client():
